# Wordle Stats
## Author: Tom Henry

## Description
Wordle Stats is a score generator that takes challenging your friends in Wordle to the next level. It provides scores for how good each guess was as well as score boosts for how many rounds it took you to solve the puzzle!

## Usage
![](wordle_stats.gif)

Enter the correct word of the day, followed by your guesses (including the correct guess) to get your final score!
